<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'fffae3',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/maitri-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'maitri_customize_register' ) ) {
	add_action( 'customize_register', 'maitri_customize_register' );
	function maitri_customize_register( $wp_customize ) {
				
		// Add Maitri customizer section
		$wp_customize->add_section(
			'maitri_layout_effects',
			array(
				'title' => __( 'Maitri Effects', 'maitri' ),
				'priority' => 24,
			)
		);
		
		// Magic Mouse
		$wp_customize->add_setting(
			'maitri_settings[magic_mouse]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'maitri_settings[magic_mouse]',
			array(
				'type' => 'select',
				'label' => __( 'Magic Mouse', 'maitri' ),
				'choices' => array(
					'enable' => __( 'Enable', 'maitri' ),
					'disable' => __( 'Disable', 'maitri' )
				),
				'settings' => 'maitri_settings[magic_mouse]',
				'section' => 'maitri_layout_effects',
				'priority' => 10
			)
		);
		
		// Logo hover
		$wp_customize->add_setting(
			'maitri_settings[logo_hover]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'maitri_settings[logo_hover]',
			array(
				'type' => 'select',
				'label' => __( 'Logo hover', 'maitri' ),
				'choices' => array(
					'enable' => __( 'Enable', 'maitri' ),
					'disable' => __( 'Disable', 'maitri' )
				),
				'section' => 'maitri_layout_effects',
				'settings' => 'maitri_settings[logo_hover]',
				'priority' => 12
			)
		);
		
		// Blog image effect
		$wp_customize->add_setting(
			'maitri_settings[img_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'maitri_settings[img_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Blog image effect', 'maitri' ),
				'choices' => array(
					'enable' => __( 'Enable', 'maitri' ),
					'disable' => __( 'Disable', 'maitri' )
				),
				'settings' => 'maitri_settings[img_effect]',
				'section' => 'maitri_layout_effects',
				'priority' => 14
			)
		);
		
		// Navigation hover
		$wp_customize->add_setting(
			'maitri_settings[nav_hover]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'maitri_settings[nav_hover]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation hover', 'maitri' ),
				'choices' => array(
					'enable' => __( 'Enable', 'maitri' ),
					'disable' => __( 'Disable', 'maitri' )
				),
				'settings' => 'maitri_settings[nav_hover]',
				'section' => 'maitri_layout_effects',
				'priority' => 16
			)
		);
		
		// Maitri effect colors
		$wp_customize->add_setting(
			'maitri_settings[maitri_color_1]', array(
				'default' => '#222222',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'maitri_settings[maitri_color_1]',
				array(
					'label' => __( 'Effect color', 'maitri' ),
					'section' => 'maitri_layout_effects',
					'settings' => 'maitri_settings[maitri_color_1]',
					'priority' => 45
				)
			)
		);
		
		$wp_customize->add_setting(
			'maitri_settings[maitri_color_2]', array(
				'default' => '#F0222C',
				'type' => 'option',
				'sanitize_callback' => 'maitri_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'maitri_settings[maitri_color_2]',
				array(
					'label' => __( 'Effect color', 'maitri' ),
					'section' => 'maitri_layout_effects',
					'settings' => 'maitri_settings[maitri_color_2]',
					'priority' => 46
				)
			)
		);
		
	}
}

//Sanitize choices.
if ( ! function_exists( 'maitri_sanitize_choices' ) ) {
	function maitri_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Sanitize colors. Allow blank value.
if ( ! function_exists( 'maitri_sanitize_hex_color' ) ) {
	function maitri_sanitize_hex_color( $color ) {
	    if ( '' === $color ) {
	        return '';
		}

	    // 3 or 6 hex digits, or the empty string.
	    if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
	        return $color;
		}

	    return '';
	}
}

// Maitri effects colors css
if ( ! function_exists( 'maitri_effect_colors_css' ) ) {
	function maitri_effect_colors_css() {
		// Get Customizer settings
		$maitri_settings = get_option( 'maitri_settings' );
		
		$maitri_color_1  	 = '#222222';
		$maitri_color_2  	 = '#F0222C';
		
		if ( isset( $maitri_settings['maitri_color_1'] ) ) {
			$maitri_color_1 = $maitri_settings['maitri_color_1'];
		}
		if ( isset( $maitri_settings['maitri_color_2'] ) ) {
			$maitri_color_2 = $maitri_settings['maitri_color_2'];
		}
		
		$lalita_settings = wp_parse_args(
			get_option( 'lalita_settings', array() ),
			lalita_get_color_defaults()
		);
		
		$maitri_extracolors = 'body #magicMouseCursor{border-color: ' . esc_attr( $maitri_color_1 ) . ';}body #magicPointer{background: ' . esc_attr( $maitri_color_2 ) . ';border-color: ' . esc_attr( $maitri_color_1 ) . ';}body #magicPointer.pointer-blur{border-color: ' . esc_attr( $maitri_color_1 ) . ';}.maitri-logo-hover .main-title a:hover {color: ' . esc_attr( $maitri_color_2 ) . ';}';
		
		return $maitri_extracolors;
	}
}

// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'maitri_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'maitri_remove_parent_dynamic_css' );
	function maitri_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'maitri_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'maitri_enqueue_parent_dynamic_css', 50 );
	function maitri_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .maitri_effect_colors_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'maitri_body_classes' ) ) {
	add_filter( 'body_class', 'maitri_body_classes' );
	function maitri_body_classes( $classes ) {
		// Get Customizer settings
		$maitri_settings = get_option( 'maitri_settings' );
		
		$magic_mouse 	    = 'enable';
		$logo_hover 		= 'enable';
		$nav_hover  		= 'enable';
		$img_effect			= 'enable';
		
		if ( isset( $maitri_settings['magic_mouse'] ) ) {
			$magic_mouse = $maitri_settings['magic_mouse'];
		}
		
		if ( isset( $maitri_settings['logo_hover'] ) ) {
			$logo_hover = $maitri_settings['logo_hover'];
		}
		
		if ( isset( $maitri_settings['nav_hover'] ) ) {
			$nav_hover = $maitri_settings['nav_hover'];
		}
		
		if ( isset( $maitri_settings['img_effect'] ) ) {
			$img_effect = $maitri_settings['img_effect'];
		}
		
		// Magic Mouse
		if ( $magic_mouse != 'disable' ) {
			$classes[] = 'maitri-magic-mouse';
		}
		
		// Logo hover
		if ( $logo_hover != 'disable' ) {
			$classes[] = 'maitri-logo-hover';
		}
		
		// Navigation hover
		if ( $nav_hover != 'disable' ) {
			$classes[] = 'maitri-nav-hover';
		}
		
		// Blog image effect
		if ( $img_effect != 'disable' ) {
			$classes[] = 'maitri-img-effect';
		}
		
		return $classes;
	}
}

// Enqueue scripts
if ( ! function_exists( 'maitri_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'maitri_scripts' );
	function maitri_scripts() {
		
		$maitri_settings = get_option( 'maitri_settings' );
		$magic_mouse		 = 'enable';
		if ( isset( $maitri_settings['magic_mouse'] ) ) {
			$magic_mouse = $maitri_settings['magic_mouse'];
		}
		
		if ( $magic_mouse != 'disable' ) {
			wp_enqueue_style( 'maitri-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/css/magic-mouse.min.css", false, LALITA_VERSION, 'all' );
			wp_enqueue_script( 'maitri-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/js/magic-mouse.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
	}
}